vox_widgets library

Our Set of often used custom widgets

Classes

AppVersionColumn
a simple wrapper that can take an navigation rail and return a version number in line with what we would like to display.
ButtonOption
what we will be using inside our more_horiz button
HPad
HPad is a horizontal padding widget.
NoiseLayer
basic noise layer, to make our colors a little more diffused looking.
NoisePainter
VoxBlurHash
VoxBlurHash is a widget that displays a blur hash
VoxButton
VoxButton is a button that is dynamic for web and mobile.
VoxButtonOptions
we need an onPressed item that can be null a title, and a trailing widget that can be null
VoxChip
VoxChip is a simple google inspired chip that we can use to display basic info in a selectable manner
VoxCircleButton
A circular button with a single icon.
VoxContainer
A custom container widget that can be decorated with a border and label.
VoxEncrustedIcon
An VoxEncrustedIcon is a simple stylized icon that will show an icon on a padded container with rounded corners, this is fairly simple, but it is used in many places in different apps.
VoxFadedScaffold
a scaffold with children being faded slightly to increase legibility.
VoxLabeledContainer
VoxLabeledContainer is a simple container that has a title and a child widget
VoxLabeledCustomInputField
VoxLabeledMultiTextField
VoxLabeledSlider
VoxLabeledTextField
VoxLinkIcon
VoxLinkIcon is a widget we use for showing a link icon in a row
VoxMoreButton
VoxMoreButton constructor
VoxMouseFollower
the mouse follower widget is a really nice looking little widget for web and desktop platforms to give some pretty cool looiing background affects.
VoxPopupButton
VoxPopupButton is a button that will display a popup menu when pressed.
VoxResponsiveBuilder
VoxResponsiveBuilder is a widget that allows us to build a different widget based on the screen size of the device. We generally want to add a padding and center the content if we are on desktop, and fill the entire context iof we are on tablet.
VoxScaffold
VoxScaffold is a widget that displays a scaffold
VoxTabButton
VoxTabButton is a widget we use for showing a button in sometype of row generally speaking, for the most part this widget is super simple, and may not be necessary. however the use case for this has shown its head in many cases so we are adding it.
VoxTitleButton
VoxTitleButton
VoxToggleButton
VoxToggleButton is a custom widget that combines a VoxButton and a CupertinoSwitch. It takes in a VoidCallback for the onPressed event, a bool to determine if the switch is enabled, and a Widget to serve as the label for the button.
VoxToggleThemeButton
VoxToggleThemeButton is a custom widget that combines a VoxButton and a CupertinoSwitch. It takes in a VoidCallback for the onPressed event, a bool to determine if the switch is enabled, and a Widget to serve as the label for the button.
VoxTooltip
A custom tooltip widget for Vox.
VPad
VPad is a vertical padding widget.

Constants

OurButtonPadding → const EdgeInsets
is this strange... yes, but we need to know what we are using here.